@@ -6,7 +6,7 @@ You can use `simple_receive.py` (or `complete_receive.py`) to receive the
 message sent.
 
 """
-from __future__ import with_statement
+from __future__ import absolute_import, unicode_literals
 
 import eventlet
 
@@ -30,10 +30,10 @@ def send_many(n):
         with connection.SimpleQueue('kombu_demo') as queue:
 
             def send_message(i):
-                queue.put({'hello': 'world%s' % (i, )})
+                queue.put({'hello': 'world%s' % (i,)})
 
             pool = eventlet.GreenPool(10)
-            for i in xrange(n):
+            for i in range(n):
                 pool.spawn(send_message, i)
             pool.waitall()
 
